//! # Movies controller
//!
//! @author Pierre Hubert

use crate::api_data::movie_api::MovieAPI;
use crate::controllers::routes::RequestResult;
use crate::data::base_request_handler::BaseRequestHandler;
use crate::data::http_request_handler::HttpRequestHandler;
use crate::helpers::movies_helper;

/// Get the list of movies of the current user
pub fn get_list(r: &mut HttpRequestHandler) -> RequestResult {
    let list = movies_helper::get_list_user(r.user_id_ref()?)?;

    r.set_response(MovieAPI::for_list(&list))
}

/// Remove a movie
pub fn delete(r: &mut HttpRequestHandler) -> RequestResult {
    let movie_id = r.post_movie_id("movieID")?;

    movies_helper::delete(&movies_helper::get_info(movie_id)?)?;

    r.success("Movie deleted.")
}